"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkFlags = void 0;
const node_process_1 = require("process");
const write_js_1 = require("../services/write.js");
const format_js_1 = require("../services/format.js");
const checkFlags = () => {
    const allowedFlags = new Set([
        '--bun',
        '--concurrency',
        '--config',
        '--debug',
        '--deno',
        '--denoAllow',
        '--denoCjs',
        '--denoDeny',
        '--enforce',
        '--envFile',
        '--exclude',
        '--failFast',
        '--filter',
        '--killPid',
        '--killPort',
        '--killRange',
        '--node',
        '--parallel',
        '--platform',
        '--quiet',
        '--watch',
        '--watchInterval',
        '-c',
        '-d',
        '-p',
        '-q',
        '-w',
        '-x',
    ]);
    const args = node_process_1.argv.slice(2);
    const unrecognizedFlags = [];
    for (const arg of args) {
        const flagName = arg.split('=')[0];
        if (!allowedFlags.has(flagName) && flagName.startsWith('-'))
            unrecognizedFlags.push(flagName);
    }
    if (unrecognizedFlags.length > 0) {
        write_js_1.Write.hr();
        write_js_1.Write.log(`${(0, format_js_1.format)('Unrecognized flags:').bold()}\n\n${unrecognizedFlags.map((flag) => (0, format_js_1.format)(flag).fail()).join('\n')}`);
        write_js_1.Write.hr();
        (0, node_process_1.exit)(1);
    }
};
exports.checkFlags = checkFlags;
